@@ -1,2 +1,2 @@
-globalVariables(c("n", "y", "x", "predicted", "lwr_95", "upr_95", "frequency",
+globalVariables(c("n", "y", "x", "predicted", "lwr_95", "upr_95", "frequency", ".SD",
                   "avg_claimsize", "avg_premium", ":=", "difference", "maanden", "maanden_tot", "id"))
